document.addEventListener("DOMContentLoaded", (event) => {
    htmx.config.scrollBehavior = "auto";
    const supportsViewTransitions = !!document.startViewTransition;
    if (!supportsViewTransitions) {
        const body = document.querySelector('body');
        body.classList.add('view-transition-fallback');
    }

    document.body.addEventListener('htmx:removingHeadElement', function(event) {
      /**
       * Retain styles during client side routing to help prevent flash of unstyled content.
       */
      const tagName = event.detail.headElement.tagName;
      const rel = event.detail.headElement.getAttribute('rel');
      if (tagName === 'LINK' && rel === 'stylesheet') {
        event.preventDefault();
      }
      else if (event.detail.headElement.tagName === 'STYLE') {
        event.preventDefault();
      }
    });

    // Work around https://github.com/bigskysoftware/htmx/issues/1384 to ensure the
    // correct attributes (especially classes) are applied during a routing event.
    document.body.addEventListener('htmx:afterSwap', function(evt) {
        const parser = new DOMParser();
        const parsedResponse = parser.parseFromString(evt.detail.xhr.response, "text/html");
        const bodyAttributes = parsedResponse.getElementsByTagName('body')[0].attributes;
        for (const attribute of bodyAttributes) {
            evt.detail.target.setAttribute(attribute.name, attribute.value);
        }
        if (!supportsViewTransitions) {
            evt.detail.target.classList.add('view-transition-fallback-settling');
        }
    });

    // Trigger fallback transitions after settle
    document.body.addEventListener('htmx:afterSettle', function(evt) {
        if (!supportsViewTransitions) {
            evt.detail.target.classList.remove('view-transition-fallback-settling');
            evt.detail.target.classList.add('view-transition-fallback-settled');
        }
    });
}, {once : true});
